# spym

A Python package and xarray accessor for loading and processing Scanning Probe Microscopy (SPM) data.

See the [documentation](https://spym-docs.readthedocs.io/en/latest/) for detailed information on installation and usage of ``spym``.
